gitflow

package
v0.1.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 28, 2017 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Repo

type Repo struct {
	// contains filtered or unexported fields
}

Repo represents a Git repository.

func NewRepo

func NewRepo(path string) (*Repo, error)

NewRepo starts a new Git repository.

func (*Repo) CheckoutTag

func (r *Repo) CheckoutTag(tag string) error

CheckoutTag returns an error if it can not switch the repository on the given tag.

func (*Repo) LastTag

func (r *Repo) LastTag() (tag string, err error)

LastTag returns the last available tag of the Git repository.

func (*Repo) LocalTag

func (r *Repo) LocalTag() (string, error)

LocalTag returns the most recent tag reachable from the defined repository.

Jump to