semver

package
v0.1.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 28, 2017 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Relationship

type Relationship struct {
	Major, Minor, Patch int8
	PreRelease, Build   string
	Upstream            int8
}

Relationship represents the difference between two versions.

func Compare

func Compare(tag1 string, tag2 string) (version Relationship, err error)

Compare returns the difference for each type and the relation between two versions.

type Version

type Version struct {
	Major, Minor, Patch uint8
	PreRelease, Build   string
}

Version represents a semantic versioning like 2.0.0. @see http://semver.org/spec/v2.0.0.html @example v1.2.3

func Parse

func Parse(tag string) (version Version, err error)

Parse returns all parts of a tag in a Version's struct.

Jump to